get_dim_info: Get information about the dimensions of a given indicator
Description
Get information about the dimensions of a given indicator
Usage
get_dim_info(indicator, lang = "PT")
Value
A data frame with dim_num (dimension number), abrv (dimension description) and versao (dimension version) for the selected indicator.
A fourth column 'nota_dsg' is present for some indicators, with additional notes about the dimensions.
Arguments
indicator
INE indicator ID as a 7 character string. Example: "0010003".
lang
One of "PT" or "EN". Default is "PT".
Details
If the indicator is not valid, returns "(PT) O codigo do indicador nao existe. / (EN) The indicator code does not exist."
Calling is_indicator_valid() before using this function is recommended.